DevicePerformanceProfile enum
Represents the performance tier of the device to adjust rendering quality.
Values
- high → const DevicePerformanceProfile
-
Flagship devices: High resolution snapshots, dense meshes, full shadows.
- medium → const DevicePerformanceProfile
-
Mid-range devices: Moderate resolution, standard meshes, standard shadows.
- low → const DevicePerformanceProfile
-
Low-end devices (2020+ budget): Lower resolution snapshots, sparse meshes, simplified shadows, throttled haptics.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DevicePerformanceProfile> - A constant List of the values in this enum, in order of their declaration.